Clazz.declarePackage("JS");
Clazz.load(["JS.JComponent"], "JS.JComponentImp", null, function(){
var c$ = Clazz.declareType(JS, "JComponentImp", JS.JComponent);
Clazz.overrideMethod(c$, "toHTML", 
function(){
return null;
});
});
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
